@@ -5,6 +5,7 @@ from datetime import datetime
 from django.db import models
 from django.core.urlresolvers import reverse
 from django.contrib.sites.models import Site
+from django.contrib.auth.models import User
 
 def full_url(link):
     current_site = Site.objects.get_current()
@@ -40,7 +41,6 @@ class NetcashGateway(models.Model):
     def save(self, *args, **kwargs):
         if not self.secret:
             self.secret = random_secret()
-
         return super(NetcashGateway, self).save(*args, **kwargs)
 
     def __unicode__(self):
@@ -84,6 +84,7 @@ class NetcashOrder(models.Model):
     request_ip = models.IPAddressField(null=True, blank=True)
     debug_info = models.CharField(max_length=255, null=True, blank=True)
     trusted = models.NullBooleanField(default=None)
+    user = models.ForeignKey(User, null=True, blank=True)
 
     def save(self, *args, **kwargs):
         self.updated_at = datetime.now()
