@@ -38,7 +38,7 @@ def data_handler(request, secret):
     try:
         gateway = NetcashGateway.objects.get(secret=secret)
     except NetcashGateway.DoesNotExist:
-        logger.warn('Invalid gateway %s. Request: %s', secret, request.raw_post_data)
+        logger.warn('Invalid gateway %s. Request: %s' % (secret, request.raw_post_data))
         raise Http404
 
     ip = request.META.get(NETCASH_IP_HEADER, None)
@@ -47,12 +47,12 @@ def data_handler(request, secret):
     try:
         order = NetcashOrder.objects.get(pk=reference)
     except NetcashOrder.DoesNotExist:
-        logger.warn('Unknown order %s. Request: %s', reference, request.raw_post_data)
+        logger.warn('Unknown order %s. Request: %s' % (reference, request.raw_post_data))
         raise Http404
 
     if order.trusted: # don't process processed orders again
-        logger.warn('Order %s is already processed. Request: %s',
-                    order.pk, request.raw_post_data)
+        logger.warn('Order %s is already processed. Request: %s' % (
+                    order.pk, request.raw_post_data))
         raise Http404
 
     if gateway.netcash_ip:
